@@ -23,22 +23,25 @@
 #'   #some charset
 #'   charset <- ISOCharacterSet$new(value = "utf8")
 #' 
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata 
+#' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOCharacterSet <- R6Class("ISOCharacterSet",
- inherit = ISOMetadataCodelistElement,
+ inherit = ISOCodeListValue,
  private = list(
    xmlElement = "MD_CharacterSetCode",
    xmlNamespacePrefix = "GMD"
  ),
  public = list(
-   initialize = function(xml = NULL, value){
-       super$initialize(xml = xml, id = private$xmlElement, value = value,
+   initialize = function(xml = NULL, value, description = NULL){
+       super$initialize(xml = xml, id = private$xmlElement, value = value, description = description, 
                         setValue = FALSE, addCodeSpaceAttr = FALSE)
    }
  )                        
 )
 
 ISOCharacterSet$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOCharacterSet, labels))
+  return(ISOCodeListValue$values(ISOCharacterSet, labels))
 }
\ No newline at end of file
