@@ -11,7 +11,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOClassification
 #'  }
 #' }
@@ -22,22 +22,26 @@
 #'  
 #'  #restricted classification
 #'  cl <- ISOClassification$new(value = "restricted")
+#'  
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata 
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOClassification <- R6Class("ISOClassification",
-   inherit = ISOMetadataCodelistElement,
+   inherit = ISOCodeListValue,
    private = list(
      xmlElement = "MD_ClassificationCode",
      xmlNamespacePrefix = "GMD"
    ),
    public = list(
-     initialize = function(xml = NULL, value){
-       super$initialize(xml = xml, id = "MD_ClassificationCode", value = value, setValue = FALSE)
+     initialize = function(xml = NULL, value, description = NULL){
+       super$initialize(xml = xml, id = private$xmlElement, value = value, 
+                        description = description, setValue = FALSE)
      }
    )                        
 )
 
 ISOClassification$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOClassification, labels))
+  return(ISOCodeListValue$values(ISOClassification, labels))
 }
\ No newline at end of file
