@@ -11,15 +11,20 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml, element, namespace, defaults)}}{
+#'  \item{\code{new(xml, defaults)}}{
 #'    This method is used to instantiate an ISOGeographicExtent
 #'  }
 #' }
 #' 
+#' @note abstract class
+#' 
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
+#' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOGeographicExtent <- R6Class("ISOGeographicExtent",
-    inherit = ISOMetadataElement,
+    inherit = ISOAbstractObject,
     private = list(
       xmlElement = "EX_GeographicExtent",
       xmlNamespacePrefix = "GMD"
@@ -27,9 +32,9 @@ ISOGeographicExtent <- R6Class("ISOGeographicExtent",
     public = list(
       #+ extentTypeCode [0..1]: ISOBaseBoolean default "true"
       extentTypeCode = NULL,
-      initialize = function(xml = NULL, element, namespace, defaults = list()){        
+      initialize = function(xml = NULL, defaults = list()){        
         defaults = list(extentTypeCode = TRUE)
-        super$initialize(xml, element, namespace, defaults)
+        super$initialize(xml, defaults = defaults)
       }
     )                                          
 )
\ No newline at end of file
