@@ -11,26 +11,37 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOGeometricObjectType
 #'  }
 #' }
 #' 
+#' @examples 
+#'   #possible values
+#'   values <- ISOGeometricObjectType$values(labels = TRUE)
+#'   
+#'   #point type
+#'   pt <- ISOGeometricObjectType$new(value = "point")
+#' 
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
+#' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOGeometricObjectType <- R6Class("ISOGeometricObjectType",
-  inherit = ISOMetadataCodelistElement,
+  inherit = ISOCodeListValue,
   private = list(
     xmlElement = "MD_GeometricObjectTypeCode",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
-    initialize = function(xml = NULL, value){
-      super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+    initialize = function(xml = NULL, value, description = NULL){
+      super$initialize(xml = xml, id = private$xmlElement, value = value,
+                       description = description, setValue = FALSE)
     }
   )                        
 )
 
 ISOGeometricObjectType$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOGeometricObjectType, labels))
+  return(ISOCodeListValue$values(ISOGeometricObjectType, labels))
 }
\ No newline at end of file
