@@ -11,26 +11,37 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOHierarchyLevel
 #'  }
 #' }
 #' 
+#' @examples 
+#'   #possible values
+#'   values <- ISOHierarchyLevel$values(labels = TRUE)
+#'   
+#'   #dataset scope
+#'   ds <- ISOHierarchyLevel$new(value = "dataset")
+#' 
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
+#' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOHierarchyLevel <- R6Class("ISOHierarchyLevel",
- inherit = ISOMetadataCodelistElement,
+ inherit = ISOCodeListValue,
  private = list(
    xmlElement = "MD_ScopeCode",
    xmlNamespacePrefix = "GMD"
  ),
  public = list(
-   initialize = function(xml = NULL, value){
-     super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+   initialize = function(xml = NULL, value, description = NULL){
+     super$initialize(xml = xml, id = private$xmlElement, value = value,
+                      description = description, setValue = FALSE)
    }
  )                        
 )
 
 ISOHierarchyLevel$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOHierarchyLevel, labels))
+  return(ISOCodeListValue$values(ISOHierarchyLevel, labels))
 }
\ No newline at end of file
