@@ -11,7 +11,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOKeywordType
 #'  }
 #' }
@@ -22,22 +22,26 @@
 #'   
 #'   #place keywordType
 #'   place <- ISOKeywordType$new(value = "place")
+#'   
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOKeywordType <- R6Class("ISOKeywordType",
- inherit = ISOMetadataCodelistElement,
+ inherit = ISOCodeListValue,
  private = list(
    xmlElement = "MD_KeywordTypeCode",
    xmlNamespacePrefix = "GMD"
  ),
  public = list(
-   initialize = function(xml = NULL, value){
-     super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+   initialize = function(xml = NULL, value, description = NULL){
+     super$initialize(xml = xml, id = private$xmlElement, value = value,
+                      description = description, setValue = FALSE)
    }
  )                        
 )
 
 ISOKeywordType$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOKeywordType, labels))
+  return(ISOCodeListValue$values(ISOKeywordType, labels))
 }
\ No newline at end of file
