@@ -11,7 +11,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOLanguage
 #'  }
 #' }
@@ -22,22 +22,26 @@
 #'   
 #'   #english language
 #'   eng <- ISOLanguage$new(value = "eng")
+#'   
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOLanguage <- R6Class("ISOLanguage",
-  inherit = ISOMetadataCodelistElement,
+  inherit = ISOCodeListValue,
   private = list(
     xmlElement = "LanguageCode",
     xmlNamespacePrefix = "GMD"
   ),
   public = list(
-   initialize = function(xml = NULL, value){
-     super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+   initialize = function(xml = NULL, value, description = NULL){
+     super$initialize(xml = xml, id = private$xmlElement, value = value,
+                      description = description, setValue = FALSE)
    }
   )                        
 )
 
 ISOLanguage$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOLanguage, labels))
+  return(ISOCodeListValue$values(ISOLanguage, labels))
 }
\ No newline at end of file
