@@ -11,7 +11,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOPresentationForm
 #'  }
 #' }
@@ -22,22 +22,26 @@
 #'   
 #'   #mapDigital type
 #'   map <- ISOPresentationForm$new(value = "mapDigital")
+#'   
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOPresentationForm <- R6Class("ISOPresentationForm",
-   inherit = ISOMetadataCodelistElement,
+   inherit = ISOCodeListValue,
    private = list(
      xmlElement = "CI_PresentationFormCode",
      xmlNamespacePrefix = "GMD"
    ),
    public = list(
-     initialize = function(xml = NULL, value){
-      super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+     initialize = function(xml = NULL, value, description = NULL){
+      super$initialize(xml = xml, id = private$xmlElement, value = value,
+                       description = description, setValue = FALSE)
      }
    )                        
 )
 
 ISOPresentationForm$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOPresentationForm, labels))
+  return(ISOCodeListValue$values(ISOPresentationForm, labels))
 }
\ No newline at end of file
