@@ -11,7 +11,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISORestriction
 #'  }
 #' }
@@ -22,22 +22,26 @@
 #'   
 #'   #copyright restriction
 #'   cr <- ISORestriction$new(value = "copyright")
+#'   
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISORestriction <- R6Class("ISORestriction",
-   inherit = ISOMetadataCodelistElement,
+   inherit = ISOCodeListValue,
    private = list(
      xmlElement = "MD_RestrictionCode",
      xmlNamespacePrefix = "GMD"
    ),
    public = list(
-     initialize = function(xml = NULL, value){
-       super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+     initialize = function(xml = NULL, value, description = NULL){
+       super$initialize(xml = xml, id = private$xmlElement, value = value,
+                        description = description, setValue = FALSE)
      }
    )                        
 )
 
 ISORestriction$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISORestriction, labels))
+  return(ISOCodeListValue$values(ISORestriction, labels))
 }
\ No newline at end of file
