@@ -22,11 +22,14 @@
 #'   
 #'   #publisher restriction
 #'   role <- ISORole$new(value = "publisher")
+#'   
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISORole <- R6Class("ISORole",
-  inherit = ISOMetadataCodelistElement,
+  inherit = ISOCodeListValue,
   private = list(
     xmlElement = "CI_RoleCode",
     xmlNamespacePrefix = "GMD"
@@ -39,5 +42,5 @@ ISORole <- R6Class("ISORole",
 )
 
 ISORole$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISORole, labels))
+  return(ISOCodeListValue$values(ISORole, labels))
 }
\ No newline at end of file
