@@ -11,7 +11,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(xml,value)}}{
+#'  \item{\code{new(xml,value, description)}}{
 #'    This method is used to instantiate an ISOTopicCategory
 #'  }
 #' }
@@ -22,22 +22,26 @@
 #'   
 #'   #biota topic
 #'   biota <- ISOTopicCategory$new(value = "biota")
+#'   
+#' @references 
+#'   ISO 19115:2003 - Geographic information -- Metadata
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOTopicCategory <- R6Class("ISOTopicCategory",
-   inherit = ISOMetadataCodelistElement,
+   inherit = ISOCodeListValue,
    private = list(
      xmlElement = "MD_TopicCategoryCode",
      xmlNamespacePrefix = "GMD"
    ),
    public = list(
-     initialize = function(xml = NULL, value){
-       super$initialize(xml = xml, id = private$xmlElement, value = value, setValue = FALSE)
+     initialize = function(xml = NULL, value, description = NULL){
+       super$initialize(xml = xml, id = private$xmlElement, value = value, description = description,
+                        addCodeListAttrs = FALSE, setValue = FALSE)
      }
    )                        
 )
 
 ISOTopicCategory$values <- function(labels = FALSE){
-  return(ISOMetadataCodelistElement$values(ISOTopicCategory, labels))
+  return(ISOCodeListValue$values(ISOTopicCategory, labels))
 }
\ No newline at end of file
