@@ -20,6 +20,22 @@ test_that("encoding",{
   md2 <- ISOBaseInteger$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOMetadataElement$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2))
+  
+})
+
+test_that("encoding with coercing",{
+  
+  #encoding
+  md <- ISOBaseInteger$new(value = "19")
+  expect_is(md, "ISOBaseInteger")
+  xml <- md$encode()
+  expect_is(xml, "XMLInternalNode")
+  
+  #decoding
+  md2 <- ISOBaseInteger$new(xml = xml)
+  xml2 <- md2$encode()
+  
+  expect_true(ISOAbstractObject$compare(md, md2))
   
 })
\ No newline at end of file
