@@ -21,6 +21,6 @@ test_that("encoding/decoding",{
   md2 <- ISOReferenceSystem$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOMetadataElement$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2))
   
 })
\ No newline at end of file
