@@ -32,6 +32,7 @@ test_that("encoding",{
   
   #decoding
   md2 <- ISOVectorSpatialRepresentation$new(xml = xml)
+  xml2 <- md2$encode()
   
-  expect_true(ISOMetadataElement$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2))
 })
\ No newline at end of file
